#!/bin/sh
#
# Name: itStp
# Date: 2013-08-19 12:00
# Copyright: (C) 2013 Iskratel
# Author:  Domen Soberl <domen.soberl@fri.uni-lj.si>
# This software licensed to Iskratel Ltd.
#
#
### BEGIN INIT INFO
# Required-Start:
# Required-Stop:
# Should-Start:
# Should-Stop:
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: start/stop STP module.
# Description: Start and stop STP module.
# chkconfig: 2345 62 9
### END INIT INFO

# Init script information
INIT_NAME=itStp.sh
DESC="STP module"
DAEMON_NAME="itStp"
BOARD_TYPE=`fw_printenv boardid | sed -n 's/.*=//p' | cut -c1-3`
if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ] || [ "$BOARD_TYPE" == "SPB" ] || [ "$BOARD_TYPE" == "SPC" ] || [ "$BOARD_TYPE" == "SPD" ] || [ "$BOARD_TYPE" == "SPE" ] || [ "$BOARD_TYPE" == "SPF" ] || [ "$BOARD_TYPE" == "SPG" ] || [ "$BOARD_TYPE" == "SPH" ]  || [ "$BOARD_TYPE" == "SPI" ] || [ "$BOARD_TYPE" == "SPJ" ] || [ "$BOARD_TYPE" == "SPK" ]; then
      PACKAGE_PATH="/opt/si2000/neroot/active/it_stp/"
else
      PACKAGE_PATH="/opt/si2000/neroot/active/"
fi
WORKING_DIR=$PACKAGE_PATH"bin"
APPLICATION=$WORKING_DIR/$DAEMON_NAME
SIGUSR1=10
SIGUSR3=64
SIGTERM=15

# Following arguments are possible: debug|consolelog|nosyslog
ARGUMENTS=""

export ITSTPPIDFILE="/var/run/$DAEMON_NAME.pid"

STOP_WAITING_LIMIT=15  # in seconds

# Source the init script functions
. /etc/init.d/init-functions

if [ "$BOARD_TYPE" == "SFI" ] || [ "$BOARD_TYPE" == "SPA" ]; then
    export LD_LIBRARY_PATH="/opt/si2000/neroot/active/it_stp/lib/"
else
    export LD_LIBRARY_PATH="/opt/si2000/neroot/active/lib/"
fi

start()
{
 local RET ERROR=
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "Starting $DESC: $DAEMON_NAME... "

  $APPLICATION $ARGUMENTS &
  echo -n $!  > $ITSTPPIDFILE
 else
  echo "$DESC already started!"
  return 0
 fi
 sleep 1

 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "Can not start $DESC !!!!"
  rm $ITSTPPIDFILE
 else
  echo "done ..."
 fi
 return 0
}

stop () {
 local RET ERROR=
 local cnt=0
 local sleepPeriod=2
 local max=`expr $STOP_WAITING_LIMIT / $sleepPeriod`

 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started"
  return 0
 fi

 echo "Stopping $DESC: $DAEMON_NAME... "
 kill "-$SIGTERM" "$PID"
 RET=$?
 if [ $RET -eq 0 ]; then
  echo " done. "
 else
  echo "failed ($RET: Unable to stop $DAEMON_NAME). "
 fi
 return 0
}

restart() {
 local RET

 echo "Restarting $DESC..."
 stop
 start
 RET=$?

 return $RET
}

tryrestart() {
 local RET

 PID=`pidof $APPLICATION`
 RET=$?
 if [ "$RET" == "" ]; then
  restart
  RET=$?
 else
  RET=7
 fi

 return $RET
}

#
# if the service does not support reload return code 3 should
# be the result...
#
reload() {
 local RET
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started"
  return 3
 fi
 echo "Reloading $DESC: $DAEMON_NAME... "
 kill "-$SIGUSR1" "$PID"
 RET=$?
 return $RET
}

forcereload() {
 local RET

 reload
 RET=$?
 if [ $RET -ne 0 ]; then
  restart
  RET=$?
 fi

 return $RET
}

status() {
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not running! "
 else
  echo "$DESC is running (PID = $PID)!"
 fi
 return 0
}

#
# In case when Http server present then Http ping over port 80 for STP must be impelemented by calling this script
#
ping() {
 local RET
 PID=`pidof $APPLICATION`
 if [ "$PID" == "" ]
 then
  echo "$DESC not started, Http ping not possible"
  return 3
 fi
 echo "Http request for $DESC: $DAEMON_NAME... "
 kill "-$SIGUSR3" "$PID"
 RET=$?
 return $RET
}

#
# Everything after this should be the same for all init scripts
#
# See the policy manual for information on actions and return codes.
#

parse() {
 case "$1" in
  start)
   start
   return $?
     ;;
  stop)
   stop
   return $?
   ;;
  restart)
   restart
   return $?
   ;;
  try-restart)
   tryrestart
   return $?
   ;;
   reload)
   reload
   return $?
   ;;
  force-reload)
   forcereload
   return $?
   ;;
  status)
   status
   return $?
   ;;
   *)
   echo "Usage: $INIT_NAME " \
   "{start | stop | restart | try-restart | reload | "\
   "force-reload | status }" >&2
   ;;
 esac

 return 1
}

parse $@
